/**************************/
/*    Nulled & Decoded    */
/*   By Magd Almuntaser   */
/*         TTMTT          */
/*   Only For WA v7.0.0   */
/**************************/

const {
    default: makeWASocket,
    downloadContentFromMessage,
    prepareWAMessageMedia,
    generateWAMessageFromContent,
  } = require('@whiskeysockets/baileys'),
  mime = require('mime-types')
const fs = require('fs'),
  { join } = require('path'),
  { default: axios } = require('axios')
function formatReceipt(phoneNumber) {
  try {
    if (phoneNumber.endsWith('@g.us')) {
      return phoneNumber
    }
    let formattedNumber = phoneNumber.replace(/\D/g, '')
    return (
      formattedNumber.startsWith('0') && (formattedNumber = '62' + formattedNumber.substr(1)),
      !formattedNumber.endsWith('@c.us') && (formattedNumber += '@c.us'),
      formattedNumber
    )
  } catch (error) {
    return phoneNumber
  }
}
async function asyncForEach(array, callback) {
  for (let index = 0; index < array.length; index++) {
    await callback(array[index], index, array)
  }
}
async function removeForbiddenCharacters(inputString) {
  return inputString.replace(/[\x00-\x1F\x7F-\x9F'\\"]/g, '')
}
async function parseIncomingMessage(incomingMessage) {
  const messageType = Object.keys(incomingMessage.message || {})[0],
    messageContent =
      messageType === 'conversation' && incomingMessage.message.conversation
        ? incomingMessage.message.conversation
        : messageType == 'imageMessage' && incomingMessage.message.imageMessage.caption
        ? incomingMessage.message.imageMessage.caption
        : messageType == 'videoMessage' && incomingMessage.message.videoMessage.caption
        ? incomingMessage.message.videoMessage.caption
        : messageType == 'extendedTextMessage' &&
          incomingMessage.message.extendedTextMessage.text
        ? incomingMessage.message.extendedTextMessage.text
        : messageType == 'messageContextInfo' &&
          incomingMessage.message.listResponseMessage?.title
        ? incomingMessage.message.listResponseMessage.title
        : messageType == 'messageContextInfo'
        ? incomingMessage.message.buttonsResponseMessage.selectedDisplayText
        : '',
    lowerCaseContent = messageContent.toLowerCase(),
    sanitizedContent = await removeForbiddenCharacters(lowerCaseContent),
    pushName = incomingMessage?.pushName || '',
    senderNumber = incomingMessage.key.remoteJid.split('@')[0]
  let imageBuffer
  if (messageType === 'imageMessage') {
    const imageStream = await downloadContentFromMessage(
      incomingMessage.message.imageMessage,
      'image'
    )
    let buffer = Buffer.from([])
    for await (const chunk of imageStream) {
      buffer = Buffer.concat([buffer, chunk])
    }
    imageBuffer = buffer.toString('base64')
  } else {
    urlImage = null
  }
  return {
    command: sanitizedContent,
    bufferImage: imageBuffer,
    from: senderNumber,
  }
}
function getSavedPhoneNumber(token) {
  return new Promise((resolve, reject) => {
    const savedPhoneNumber = token
    savedPhoneNumber
      ? setTimeout(() => {
          resolve(savedPhoneNumber)
        }, 2000)
      : reject(new Error('Nomor telepon tidak ditemukan.'))
  })
}
const prepareMediaMessage = async (socket, mediaOptions) => {
  try {
    const preparedMedia = await prepareWAMessageMedia(
        { [mediaOptions.mediatype]: { url: mediaOptions.media } },
        { upload: socket.waUploadToServer }
      ),
      messageKey = mediaOptions.mediatype + 'Message'
    if (mediaOptions.mediatype === 'document' && !mediaOptions.fileName) {
      const fileNameRegex = new RegExp(/.*\/(.+?)\./),
        fileNameMatch = fileNameRegex.exec(mediaOptions.media)
      mediaOptions.fileName = fileNameMatch[1]
    }
    mimetype = mime.lookup(mediaOptions.media)
    if (!mimetype) {
      const response = await axios.head(mediaOptions.media)
      mimetype = response.headers['content-type']
    }
    mediaOptions.media.includes('.cdr') && (mimetype = 'application/cdr')
    preparedMedia[messageKey].caption = mediaOptions?.caption
    preparedMedia[messageKey].mimetype = mimetype
    preparedMedia[messageKey].fileName = mediaOptions.fileName
    mediaOptions.mediatype === 'video' &&
      ((preparedMedia[messageKey].jpegThumbnail = Uint8Array.from(
        fs.readFileSync(
          join(process.cwd(), 'public', 'images', 'video-cover.png')
        )
      )),
      (preparedMedia[messageKey].gifPlayback = false))
    let userJid = socket.user.id.replace(/:\d+/, '')
    return await generateWAMessageFromContent(
      '',
      { [messageKey]: { ...preparedMedia[messageKey] } },
      { userJid: userJid }
    )
  } catch (prepareError) {
    return console.log('error prepare', prepareError), false
  }
}
module.exports = {
  formatReceipt: formatReceipt,
  asyncForEach: asyncForEach,
  removeForbiddenCharacters: removeForbiddenCharacters,
  parseIncomingMessage: parseIncomingMessage,
  getSavedPhoneNumber: getSavedPhoneNumber,
  prepareMediaMessage: prepareMediaMessage,
}
