/**************************/
/*    Nulled & Decoded    */
/*   By Magd Almuntaser   */
/*         TTMTT          */
/*   Only For WA v7.0.0   */
/**************************/

const { Boom } = require('@hapi/boom')
const {
  default: makeWASocket,
  Browsers,
  fetchLatestBaileysVersion,
  useMultiFileAuthState,
  makeCacheableSignalKeyStore,
  DisconnectReason,
} = require('@whiskeysockets/baileys')
const QRCode = require('qrcode'),
  fs = require('fs'),
  {
    isExistsEqualCommand,
    isExistsContainCommand,
    getUrlWebhook,
	getDevice,
  } = require('./database/model')
let sock = [],
  qrcode = [],
  pairingCode = [],
  intervalStore = []
const { setStatus } = require('./database/index'),
  { IncomingMessage } = require('./controllers/incomingMessage'),
  {
    formatReceipt,
    getSavedPhoneNumber,
    prepareMediaMessage,
  } = require('./lib/helper'),
  MAIN_LOGGER = require('./lib/pino'),
  NodeCache = require('node-cache'),
  logger = MAIN_LOGGER.child({}),
  msgRetryCounterCache = new NodeCache(),
  connectToWhatsApp = async (
    token,
    socket = null,
    usePairingCode = false
  ) => {
    if (typeof qrcode[token] !== 'undefined' && !usePairingCode) {
      return (
        socket?.emit('qrcode', {
          token: token,
          data: qrcode[token],
          message: 'please scan with your Whatsapp Accountt',
        }),
        {
          status: false,
          sock: sock[token],
          qrcode: qrcode[token],
          message: 'please scan',
        }
      )
    }
    if (typeof pairingCode[token] !== 'undefined' && usePairingCode) {
      return (
        socket?.emit('code', {
          token: token,
          data: pairingCode[token],
          message:
            'Go to whatsapp -> link device -> link with phone number, and pairing with this code.',
        }),
        {
          status: false,
          code: pairingCode[token],
          message: 'pairing with that code',
        }
      )
    }
    try {
      let userId = sock[token].user.id.split(':')
      userId = userId[0] + '@s.whatsapp.net'
      const ppUrl = await getPpUrl(token, userId)
      return (
        socket?.emit('connection-open', {
          token: token,
          user: sock[token].user,
          ppUrl: ppUrl,
        }),
        delete qrcode[token],
        delete pairingCode[token],
        {
          status: true,
          message: 'Already connected',
        }
      )
    } catch (error) {
      socket?.emit('message', {
        token: token,
        message: 'Connecting.. (1)..',
      })
    }
    const { version: version, isLatest: isLatest } =
      await fetchLatestBaileysVersion()
    console.log(
      'You re using whatsapp gateway M Pedia v7.0.0.9 - Contact admin if any trouble : 6292298859671'
    )
    console.log('using WA v' + version.join('.') + ', isLatest: ' + isLatest)
    const { state: state, saveCreds: saveCreds } =
      await useMultiFileAuthState('./credentials/' + token)
    sock[token] = makeWASocket({
      version: version,
      browser: Browsers.macOS('Chrome', 'Mpedia'),
      logger: logger,
      printQRInTerminal: false,
	  keepAliveIntervalMs: 15000,
	  connectTimeoutMs: 15000,
	  fireInitQueries: false,
	  markOnlineOnConnect: true,
	  defaultQueryTimeoutMs: undefined,
      auth: {
        creds: state.creds,
        keys: makeCacheableSignalKeyStore(state.keys, logger),
      },
      msgRetryCounterCache: msgRetryCounterCache,
      generateHighQualityLinkPreview: true,
    })
    if (usePairingCode && 'me' in state.creds === false) {
      const savedPhoneNumber = await getSavedPhoneNumber(token)
      try {
        const pairingCodeNew = await sock[token].requestPairingCode(savedPhoneNumber)
        pairingCode[token] = pairingCodeNew
      } catch (error) {
        socket?.emit('message', {
          token: token,
          message: 'Time out, please refresh page',
        })
      }
      socket?.emit('code', {
        token: token,
        data: pairingCode[token],
        message:
          'Go to whatsapp -> link device -> link with phone number, and pairing with this code.',
      })
    }
    return (
      sock[token].ev.process(async (event) => {
        if (event['connection.update']) {
          const connectionUpdate = event['connection.update'],
            {
              connection: connection,
              lastDisconnect: lastDisconnect,
              qr: qr,
            } = connectionUpdate
          if (connection === 'close') {
            const message = lastDisconnect.error?.output?.payload?.message,
              error = lastDisconnect.error?.output?.payload?.error
            if (
              (lastDisconnect?.error instanceof Boom)?.output?.statusCode !==
              DisconnectReason.loggedOut
            ) {
              delete qrcode[token]
              socket?.emit('message', {
                token: token,
                message: 'Connecting..',
              })
              if (message == 'QR refs attempts ended') {
                sock[token].ws.close()
                delete qrcode[token]
                delete pairingCode[token]
                delete sock[token]
                socket?.emit('message', {
                  token: token,
                  message: 'Request QR ended. reload web to scan again',
                })
                return
              }
              ;(error === 'Unauthorized' ||
                error === 'Method Not Allowed') &&
                (setStatus(token, 'Disconnect'),
                clearConnection(token),
                connectToWhatsApp(token, socket))
              message === 'Stream Errored (restart required)' &&
                connectToWhatsApp(token, socket)
              message === 'Connection was lost' && delete sock[token]
            } else {
              setStatus(token, 'Disconnect')
              console.log('Connection closed. You are logged out.')
              socket?.emit('message', {
                token: token,
                message: 'Connection closed. You are logged out.',
              })
              clearConnection(token)
              connectToWhatsApp(token, socket)
            }
          }
          qr &&
            (console.log('new qr', token),
            QRCode.toDataURL(qr, function (error, qrData) {
              if (error) {
                console.log(error)
              }
              qrcode[token] = qrData
              connectToWhatsApp(token, socket, usePairingCode)
            }))
          if (connection === 'open') {
            console.log('OPEN OPEN OPEN')
            setStatus(token, 'Connected')
            delete qrcode[token]
            delete pairingCode[token]
            let userId = sock[token].user.id.split(':')
            userId = userId[0] + '@s.whatsapp.net'
            const profilePictureUrl = await getPpUrl(token, userId)
            socket?.emit('connection-open', {
              token: token,
              user: sock[token].user,
              ppUrl: profilePictureUrl,
            })
            delete qrcode[token]
            delete pairingCode[token]
          }
		  let reasonEr = lastDisconnect?.error?.output?.statusCode;
			if (reasonEr === DisconnectReason.connectionLost) {
				console.log("Connection Lost, Reconnecting...");
				connectToWhatsApp(token, socket)
			}
			if (reasonEr === DisconnectReason.connectionClosed) {
				console.log("Connection Close, Reconnecting...");
				connectToWhatsApp(token, socket)
			}
			if (reasonEr === DisconnectReason.timedOut) {
				console.log("Connection TimedOut, Reconnecting...");
				connectToWhatsApp(token, socket)
			}
        }
        if (event['creds.update']) {
          const credsUpdate = event['creds.update']
          saveCreds(credsUpdate)
        }
        if (event['messages.upsert']) {
          const messagesUpsert = event['messages.upsert']
          IncomingMessage(messagesUpsert, sock[token])
        }
      }),
	  setInterval(async () => {
		if (sock[token] && sock[token].user) {
			console.log('Sending keep-alive message to keep connection alive');
			try {
				await sock[token].sendPresenceUpdate('available');
				//await sendText(token, 'xxxxxxxx', '1');
			} catch (error) {

			}
		}
	  }, 30000),
	  sock[token].ws.on('CB:call', async call => {
		  const getDeviceWa = await getDevice(sock[token].user.id.split(':')[0]);
          const TextCall = getDeviceWa[0].reject_message;
          if (TextCall !== null) {
				if (call.content[0].tag == 'offer') {
					const callerJid = call.content[0].attrs['call-creator']
					const {  platform, notify, t } = call.attrs;
					const caption = TextCall;
					await sock[token].sendMessage(callerJid, { text: caption });
				}
          }
	  }),
	  sock[token].ev.on('call', async (node) => {
			const getDeviceWa = await getDevice(sock[token].user.id.split(':')[0]);
			const reject_call = getDeviceWa[0].reject_call;
			const webhook_reject_call = getDeviceWa[0].webhook_reject_call;
			if (reject_call === 1 || webhook_reject_call === 1) {
				const { from, id, status } = node[0]
				if (status == 'offer') {
					const sendresult = {
						tag: 'call',
						attrs: {
							from: sock[token].user.id,
							to: from,
							id: sock[token].generateMessageTag(),
						},
						content: [
							{
								tag: 'reject',
								attrs: {
									'call-id': id,
									'call-creator': from,
									count: '0',
								},
								content: undefined,
							},
						],
					}
					await sock[token].query(sendresult)
				}
			}
	  }),
      {
        sock: sock[token],
        qrcode: qrcode[token],
      }
    )
  }
async function connectWaBeforeSend(waToken) {
  let isConnected = undefined,
    connectionResult
  connectionResult = await connectToWhatsApp(waToken)
  await connectionResult.sock.ev.on('connection.update', (update) => {
    const { connection: connectionStatus, qr: qrCode } = update
    connectionStatus === 'open' && (isConnected = true)
    qrCode && (isConnected = false)
  })
  let retryCount = 0
  while (typeof isConnected === 'undefined') {
    retryCount++
    if (retryCount > 4) {
      break
    }
    await new Promise((resolve) => setTimeout(resolve, 1000))
  }
  return isConnected
}
const sendText = async (waToken, recipient, message) => {
    try {
      const sendMessageResult = await sock[waToken].sendMessage(
        formatReceipt(recipient),
        { text: message }
      )
      return sendMessageResult
    } catch (error) {
      return false
    }
  },
  sendMessage = async (waToken, recipient, message) => {
    try {
      const sendMessageResult = await sock[waToken].sendMessage(
        formatReceipt(recipient),
        JSON.parse(message)
      )
      return sendMessageResult
    } catch (error) {
      return false
    }
  }
async function sendLocation(
  waToken,
  recipient,
  latitude,
  longitude
) {
    try {
      const sendLocationResult = await sock[waToken].sendMessage(
        formatReceipt(recipient),
        {
			location: { degreesLatitude: latitude, degreesLongitude: longitude }
		}
      )
      return sendLocationResult
    } catch (error) {
      return false
    }
}
async function sendVcard(
  waToken,
  recipient,
  name,
  phone
) {
    try {
      const vcard = 'BEGIN:VCARD\n' // metadata of the contact card
            + 'VERSION:3.0\n' 
            + 'FN:'+name+'\n' // full name
            + 'TEL;type=CELL;type=VOICE;waid='+phone+':+'+phone+'\n' // WhatsApp ID + phone number
            + 'END:VCARD';
      const sendLocationResult = await sock[waToken].sendMessage(
        formatReceipt(recipient),
        {
			contacts: { 
               displayName: name, 
               contacts: [{ vcard }] 
            }
		}
      )
      return sendLocationResult
    } catch (error) {
      return false
    }
}
async function sendMedia(
  waToken,
  recipient,
  mediaType,
  mediaPath,
  caption,
  message,
  fileName
) {
  const formattedRecipient = formatReceipt(recipient)
  let userId = sock[waToken].user.id.replace(/:\d+/, '')
  if (mediaType == 'audio') {
    return await sock[waToken].sendMessage(formattedRecipient, {
      audio: { url: mediaPath },
      ptt: true,
      mimetype: 'audio/mpeg',
    })
  }
  const mediaMessage = await prepareMediaMessage(sock[waToken], {
      caption: caption ? caption : '',
      fileName: fileName,
      media: mediaPath,
      mediatype:
        mediaType !== 'video' && mediaType !== 'image' ? 'document' : mediaType,
    }),
    forwardMessage = { ...mediaMessage.message }
  return await sock[waToken].sendMessage(formattedRecipient, {
    forward: {
      key: {
        remoteJid: userId,
        fromMe: true,
      },
      message: forwardMessage,
    },
  })
}
async function sendButtonMessage(
  waToken,
  recipient,
  buttons,
  message,
  footer,
  imageUrl
) {
  let url = 'url'
  try {
    const buttonArray = buttons.map((button, index) => {
      return {
        buttonId: index,
        buttonText: { displayText: button.displayText },
        type: 1,
      }
    })
    if (imageUrl) {
      var buttonMessage = {
        image:
          url == 'url'
            ? { url: imageUrl }
            : fs.readFileSync('src/public/temp/' + imageUrl),
        caption: message,
        footer: footer,
        buttons: buttonArray,
        headerType: 4,
        viewOnce: true,
      }
    } else {
      var buttonMessage = {
        text: message,
        footer: footer,
        buttons: buttonArray,
        headerType: 1,
        viewOnce: true,
      }
    }
    const sendButtonMessageResult = await sock[waToken].sendMessage(
      formatReceipt(recipient),
      buttonMessage
    )
    return sendButtonMessageResult
  } catch (error) {
    return console.log(error), false
  }
}
async function sendTemplateMessage(
  waToken,
  recipient,
  templateButtons,
  message,
  footer,
  imageUrl
) {
  try {
    if (imageUrl) {
      var templateMessage = {
        caption: message,
        footer: footer,
        viewOnce: true,
        templateButtons: templateButtons,
        image: { url: imageUrl },
        viewOnce: true,
      }
    } else {
      var templateMessage = {
        text: message,
        footer: footer,
        viewOnce: true,
        templateButtons: templateButtons,
      }
    }
    const sendTemplateMessageResult = await sock[waToken].sendMessage(
      formatReceipt(recipient),
      templateMessage
    )
    return sendTemplateMessageResult
  } catch (error) {
    return console.log(error), false
  }
}
async function sendListMessage(
  waToken,
  recipient,
  sections,
  message,
  footer,
  title,
  buttonText
) {
  try {
    const listMessage = {
        text: message,
        footer: footer,
        title: title,
        buttonText: buttonText,
        sections: [sections],
      },
      sendListMessageResult = await sock[waToken].sendMessage(
        formatReceipt(recipient),
        listMessage,
        { ephemeralExpiration: 604800 }
      )
    return sendListMessageResult
  } catch (error) {
    return console.log(error), false
  }
}
async function sendPollMessage(
  waToken,
  recipient,
  pollName,
  pollValues,
  selectableCount
) {
  try {
    const sendPollMessageResult = await sock[waToken].sendMessage(
      formatReceipt(recipient),
      {
        poll: {
          name: pollName,
          values: pollValues,
          selectableCount: selectableCount,
        },
      }
    )
    return sendPollMessageResult
  } catch (error) {
    return console.log(error), false
  }
}
async function fetchGroups(waToken) {
  try {
	if (typeof sock[waToken] === 'undefined') {
      const connectionResult = await connectWaBeforeSend(waToken)
      if (!connectionResult) {
        return false
      }
    }
    let allGroups = await sock[waToken].groupFetchAllParticipating(),
      groupList = Object.entries(allGroups)
        .slice(0)
        .map((groupEntry) => groupEntry[1])
    return groupList
  } catch (error) {
    return false
  }
}
async function isExist(waToken, phoneNumber) {
  try {
    if (typeof sock[waToken] === 'undefined') {
      const connectionResult = await connectWaBeforeSend(waToken)
      if (!connectionResult) {
        return false
      }
    }
    if (phoneNumber.includes('@g.us')) {
      return true
    } else {
      const [isOnWhatsApp] = await sock[waToken].onWhatsApp('+' + phoneNumber)
      return phoneNumber.length > 11 ? isOnWhatsApp : true
    }
  } catch (error) {
    return false
  }
}
async function getPpUrl(waToken, userId, error) {
  let profilePictureUrl
  try {
    return (
      (profilePictureUrl = await sock[waToken].profilePictureUrl(userId)),
      profilePictureUrl
    )
  } catch (error) {
    return 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/6b/WhatsApp.svg/1200px-WhatsApp.svg.png'
  }
}
async function deleteCredentials(waToken, socket = null) {
  socket !== null &&
    socket.emit('message', {
      token: waToken,
      message: 'Logout Progres..',
    })
  try {
    if (typeof sock[waToken] === 'undefined') {
      const connectionResult = await connectWaBeforeSend(waToken)
      connectionResult && (sock[waToken].logout(), delete sock[waToken])
    } else {
      sock[waToken].logout()
      delete sock[waToken]
    }
    return (
      delete qrcode[waToken],
      clearInterval(intervalStore[waToken]),
      setStatus(waToken, 'Disconnect'),
      socket != null &&
        (socket.emit('Unauthorized', waToken),
        socket.emit('message', {
          token: waToken,
          message: 'Connection closed. You are logged out.',
        })),
      fs.existsSync('./credentials/' + waToken) &&
        fs.rmSync(
          './credentials/' + waToken,
          {
            recursive: true,
            force: true,
          },
          (error) => {
            if (error) {
              console.log(error)
            }
          }
        ),
      {
        status: true,
        message: 'Deleting session and credential',
      }
    )
  } catch (error) {
    return (
      console.log(error),
      {
        status: true,
        message: 'Nothing deleted',
      }
    )
  }
}
function clearConnection(waToken) {
  clearInterval(intervalStore[waToken])
  delete sock[waToken]
  delete qrcode[waToken]
  setStatus(waToken, 'Disconnect')
  fs.existsSync('./credentials/' + waToken) &&
    (fs.rmSync(
      './credentials/' + waToken,
      {
        recursive: true,
        force: true,
      },
      (error) => {
        if (error) {
          console.log(error)
        }
      }
    ),
    console.log('credentials/' + waToken + ' is deleted'))
}
async function initialize(req, res) {
  const { token: token } = req.body
  if (token) {
    const fs = require('fs'),
      credentialsPath = './credentials/' + token
    if (fs.existsSync(credentialsPath)) {
      sock[token] = undefined
      const connectionResult = await connectWaBeforeSend(token)
      return connectionResult
        ? res.status(200).json({
            status: true,
            message: token + ' connection restored',
          })
        : res.status(200).json({
            status: false,
            message: token + ' connection failed',
          })
    }
    return res.send({
      status: false,
      message: token + ' Connection failed,please scan first',
    })
  }
  return res.send({
    status: false,
    message: 'Wrong Parameterss',
  })
}
module.exports = {
  connectToWhatsApp,
  sendText,
  sendLocation,
  sendVcard,
  sendMedia,
  sendButtonMessage,
  sendTemplateMessage,
  sendListMessage,
  sendPollMessage,
  isExist,
  getPpUrl,
  fetchGroups,
  deleteCredentials,
  sendMessage,
  initialize,
  connectWaBeforeSend,
  sock,
}
